==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/src/com/necsoft/hinemos/webclient/repository/business/GetAgentListTableDefineBusiness.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.repository.business;

import java.util.ArrayList;
import java.util.Locale;
import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebHeaderInvalidException;
import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
import com.necsoft.hinemos.webclient.repository.action.GetAgentListTableDefine;

/**
 * This class used to display Agent List Business
 *
 */
public class GetAgentListTableDefineBusiness {

    public ArrayList<TableColumnInfoJs> getAgentListTableDefine(Locale locale)
            throws HinemosWebException {
        // 中間変数を宣言
        ArrayList<TableColumnInfoJs> tblDefine = null;
        // ...(GetAgentListTableDefine)を取得
        tblDefine = GetAgentListTableDefine.get(locale);
        // ...テーブルヘッダー定義データの項目数チェック
        if (tblDefine.size() != RepositoryConstants.AGENT_LIST_TABLE_HEADER_NUM) {
            // 項目数が不足の場合
            throw new HinemosWebHeaderInvalidException("exception.header.number");
        }

        return tblDefine;
    }
}

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/src/com/necsoft/hinemos/webclient/repository/business/GetAgentListTableDefineBusiness.java <==
/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.repository.business;

import java.util.ArrayList;
import java.util.Locale;
import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
import com.necsoft.hinemos.webclient.exception.HinemosWebException;
import com.necsoft.hinemos.webclient.exception.HinemosWebHeaderInvalidException;
import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
import com.necsoft.hinemos.webclient.repository.action.GetAgentListTableDefine;

/**
 * This class used to display Agent List Business
 *
 */
public class GetAgentListTableDefineBusiness {

    public ArrayList<TableColumnInfoJs> getAgentListTableDefine(Locale locale, boolean isManagerIpRequired)
            throws HinemosWebException {
        // 中間変数を宣言
        ArrayList<TableColumnInfoJs> tblDefine = null;
        // ...(GetAgentListTableDefine)を取得
        tblDefine = GetAgentListTableDefine.get(locale, isManagerIpRequired);
        // ...テーブルヘッダー定義データの項目数チェック
        if (isManagerIpRequired) {
            if (tblDefine.size() != RepositoryConstants.AGENT_LIST_TABLE_HEADER_NUM_WITH_MANAGER) {
                // 項目数が不正の場合
                throw new HinemosWebHeaderInvalidException(
                        "exception.header.number");
            }
        } else {
            if (tblDefine.size() != RepositoryConstants.AGENT_LIST_TABLE_HEADER_NUM_WITHOUT_MANAGER) {
                // 項目数が不正の場合
                throw new HinemosWebHeaderInvalidException(
                        "exception.header.number");
            }
        }
        return tblDefine;
    }
}
